<?php

namespace Drupal\google_json_api\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides administration/configuration form for module settings.
 *
 * @package Drupal\google_json_api\Form
 */
class GoogleJsonAPIConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_json_api_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form = parent::buildForm($form, $form_state);

    $config = $this->config('google_json_api.settings');

    $form['search_json_endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google Custom Search JSON API Endpoint:'),
      '#default_value' => $config->get('search_json_endpoint'),
      '#description' => $this->t('Refer to <a href="@jsonapidocs">Google Custom Search
        JSON API Documentation</a>.',
        ['@jsonapidocs' => $config->get('google_json_api.google_json_api_documentation')]),
    ];

    $form['search_site_restricted_json_endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google Custom Search Site Restricted JSON API Endpoint:'),
      '#default_value' => $config->get('search_site_restricted_json_endpoint'),
      '#description' => $this->t('Refer to <a href="@jsonapidocs">Google Custom Search Site Restricted
        JSON API Documentation</a>.',
        ['@jsonapidocs' => $config->get('google_json_api.google_json_api_restricted_documentation')]),
    ];

    $form['google_custom_search_documentation'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google Custom Search Overview:'),
      '#default_value' => $config->get('google_custom_search_documentation'),
      '#description' => $this->t('Link to the Google Custom Search JSON API overview.'),
    ];

    $form['google_json_api_documentation'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google Custom Search JSON API Documentation:'),
      '#default_value' => $config->get('google_json_api_documentation'),
      '#description' => $this->t('Link to the Google Custom Search JSON API Documentation'),
    ];

    $form['google_json_api_restricted_documentation'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google Custom Search Site Restricted JSON API Documentation:'),
      '#default_value' => $config->get('google_json_api_restricted_documentation'),
      '#description' => $this->t('Link to the Google Custom Search Site Restricted JSON API Documentation'),
    ];

    return $form;

  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $this->config('google_json_api.settings');

    $config->set('google_json_api.search_json_endpoint',
      $form_state->getValue('search_json_endpoint'));
    $config->set('google_json_api.search_site_restricted_json_endpoint',
      $form_state->getValue('search_site_restricted_json_endpoint'));
    $config->set('google_json_api.google_custom_search_documentation',
      $form_state->getValue('google_custom_search_documentation'));
    $config->set('google_json_api.google_json_api_documentation',
      $form_state->getValue('google_json_api_documentation'));
    $config->set('google_json_api.google_json_api_restricted_documentation',
      $form_state->getValue('google_json_api_restricted_documentation'));

    $config->save();

    return parent::submitForm($form, $form_state);

  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'google_json_api.settings',
    ];
  }

}
